ExprValueType

Trait ExprValueType 

pub trait ExprValueType {
    type ValueType;
}
Row inference types and traits. Resolves the Rust value type for a column or typed expression.

Implemented for:

  • Column ZSTs (proc macro generates alongside ColumnValueType)
  • SQLExpr<T, N, A> where T: SQLTypeToRust<D> and N: WrapNullable

For SQL<'a, V> (raw SQL), ValueType = () — the user must specify the concrete row type via turbofish (.all::<T>()).

Required Associated Types

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<E> ExprValueType for AliasedExpr<E>
where E: ExprValueType,

Source

impl<Lhs, Rhs, Op> ExprValueType for ColumnBinOp<Lhs, Rhs, Op>
where Lhs: ExprValueType,

Source

impl<T> ExprValueType for ColumnNeg<T>
where T: ExprValueType,

Source

impl<V, T, N, A> ExprValueType for SQLExpr<'_, V, T, N, A>

Source

impl<V> ExprValueType for SQL<'_, V>
where V: SQLParam,

Raw SQL fallback — value type is (), user must specify the concrete type.