pub enum StatementTarget {
Table {
schema: Option<String>,
name: String,
columns: Vec<String>,
},
Index {
schema: Option<String>,
name: String,
unique: bool,
columns: Vec<String>,
},
View {
schema: Option<String>,
name: String,
},
Enum {
schema: Option<String>,
name: String,
values: Vec<String>,
},
Unclassified,
}Available on crate feature
std only.Expand description
What a migration statement creates, when that is decidable from its text.
Variants
Table
CREATE TABLE [IF NOT EXISTS] <name> (<columns>).
Fields
Index
CREATE [UNIQUE] INDEX [CONCURRENTLY] [IF NOT EXISTS] <name> ON ....
Fields
View
CREATE VIEW <name> AS ....
Fields
Enum
CREATE TYPE <name> AS ENUM (<values>).
Fields
Unclassified
Anything else. Never provable, therefore never skippable.
Implementations
Sourceimpl StatementTarget
impl StatementTarget
Sourcepub const fn is_classified(&self) -> bool
pub const fn is_classified(&self) -> bool
Whether this statement kind can ever be proven already-applied.